#[non_exhaustive]pub enum ConnectError {
Tcp(Error),
Tls(Error),
Start(StartSessionError),
Auth(RpcError),
Rebind(RpcError),
ProxyConnect(Box<dyn Error + Send + Sync + 'static>),
Canceled,
}Expand description
Errors arising at SessionBuilder::connect time.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Tcp(Error)
An error occurred when establishing a TCP connection to the ngrok server.
Tls(Error)
A TLS handshake error occurred.
This is usually a certificate validation issue, or an attempt to connect to something that doesn’t actually speak TLS.
Start(StartSessionError)
An error occurred when starting the ngrok session.
This might occur when there’s a protocol mismatch interfering with the heartbeat routine.
Auth(RpcError)
An error occurred when attempting to authenticate.
Rebind(RpcError)
An error occurred when rebinding tunnels during a reconnect
ProxyConnect(Box<dyn Error + Send + Sync + 'static>)
An error arising from a failure to connect through a proxy.
Canceled
The (re)connect function gave up.
This will never be returned by the default connect function, and is instead used to cancel the reconnect loop.